atomate.common.firetasks.tests package — atomate 0.9.2 documentation

# atomate.common.firetasks.tests package

## Submodules

## atomate.common.firetasks.tests.test_glue_tasks module

class `atomate.common.firetasks.tests.test_glue_tasks.` `TestCopyFilesFromCalcLoc`(methodName='runTest')

  Bases: `atomate.utils.testing.AtomateTest`

  classmethod `setUpClass`()

    Hook method for setting up class fixture before running tests in the class.

  `test_copyfilesfromcalcloc`()

class `atomate.common.firetasks.tests.test_glue_tasks.` `TestCreateFolder`(methodName='runTest')

  Bases: `atomate.utils.testing.AtomateTest`

  `test_createfolder`()

class `atomate.common.firetasks.tests.test_glue_tasks.` `TestDeleteFiles`(methodName='runTest')

  Bases: `atomate.utils.testing.AtomateTest`

  `test_cleanupfiles`()

class `atomate.common.firetasks.tests.test_glue_tasks.` `TestPassCalcLocs`(methodName='runTest')

  Bases: `atomate.utils.testing.AtomateTest`

  `test_passcalclocs`()

## atomate.common.firetasks.tests.test_parse_outputs module

class `atomate.common.firetasks.tests.test_parse_outputs.` `TestDrone`

  Bases: `pymatgen.apps.borg.hive.AbstractDrone`

  `__init__`()

    Initialize self. See help(type(self)) for accurate signature.

  `assimilate`(path)

    Assimilate data in a directory path into a pymatgen object. Because of the quirky nature of Python”s multiprocessing, the object must support pymatgen’s as_dict() for parallel processing.

    Args:

      path: directory path

    Returns:

      An assimilated object

  `get_valid_paths`(path)

    Checks if path contains valid data for assimilation, and then returns the valid paths. The paths returned can be a list of directory or file paths, depending on what kind of data you are assimilating. For example, if you are assimilating VASP runs, you are only interested in directories containing vasprun.xml files. On the other hand, if you are interested converting all POSCARs in a directory tree to cifs for example, you will want the file paths.

    Args:
      path: input path as a tuple generated from os.walk, i.e.,

        (parent, subdirs, files).

    Returns:

      List of valid dir/file paths for assimilation

class `atomate.common.firetasks.tests.test_parse_outputs.` `TestToDbTask`(methodName='runTest')

  Bases: `atomate.utils.testing.AtomateTest`

  `test_ToDbTask`()

## Module contents